**********************************************************
* Introduzione all'analisi dei dati longitudinali
* CAP 5:	ANALISI DELLE SEQUENZE 
**********************************************************
* seq_sa_des.do
* descrizione delle sequenze individuali e  
* OMA: confronto con una sequenza di riferimento 
* - tabelle 3 e 4
* - figura  2
* VERSIONE: AGOSTO 2013
***********************************************************
*version 12.1 
global sa F:\longi\
use $sa\data\carriereIT_lungo.dta, clear 
set dp comma 

***********************************************************
* Standardizzazione delle Sequenze a 5 anni di osservazione  
***********************************************************
bys id: gen nr=_n
keep if nr<=61
egen nrmax=max(nr), by(id)  
keep if nrmax==61 

* elimina il primo mese artificiale 
drop if nr==1 
replace time=time-1

* riduciamo lo State Space 
recode empstat 31 32 33=30 21 22=20
lab def empstat 30 "30. non FL" 20"20. disocc" , modify 
tab empstat



*******************************************
* Descrizione
*******************************************
*--> il help file del pachetto SQ 
help sq 

tab1 empstat bcoho genere 

*******************************************
* Definizione delle Sequenze: SQSET
*******************************************
* definisce: Status, ID e TEMPO  

sqset empstat id time

*******************************************
* Analisi delle Sequenze 
******************************************* 
* Descrizione 
******************************************* 

*<-  Overall length of sequence in status 11-30
egen dur11=sqlength(), element(11)	
egen dur12=sqlength(), element(12)
egen dur13=sqlength(), element(13)
egen dur20=sqlength(), element(20)
egen dur30=sqlength(), element(30)	
*<-  Number of different elements in sequence 
egen elemnum = sqelemcount()         
*<-  Number of episodes 
egen chnum = sqepicount()            
*<-  Number of episodes of element 13
egen epinum13 = sqepicount(), element(13) 
*<-  Number of episodes of element 20
egen epinum20 = sqepicount(), element(20) 
******************************************
* Calcolare le distanze con OPTIMAL MATCHING 
******************************************
*<- Default: Indel = 1, subcost = 2
* matrice dei costi per la sostituzione  
# delimit ;
matrix scostw2 = 
(0,1,1.5,2,3
\1,0,1.5,2,3
\1.5,1.5,0,2,3
\2,2,2,0,2
\3,3,3,2,0);
# delimit cr

*******************************************
* Sequenza di RIFERIMENTO 
*******************************************
* id 75803 e' una sequenza di lavoro permanente continua, la durata in status 13 e' quindi di 60 mesi 
sqom,refseqid(75803)                                 
*????sqom, ideal(12:60)
rename _SQdist Disrefnw

* in alternativa: usa la matrice dei cosit definita sopra: scostw2
sqom, subcost(scostw2) indel(1) refseqid(75803)
rename _SQdist Disrefw2_1
/*sqom, subcost(scostw2) indel(3) refseqid(75803)
rename _SQdist Disrefw2_3

mean Disrefnw Disrefw2_1 Disrefw2_3, over(genere), if time==1 
mean Disrefnw Disrefw2_1 , over(bcoho) , if time==1       
*/
                                  


******************
* 	TABELLA 1
******************
* compare means 
recode Disrefnw 0=0 0.01/max=1, gen(dis01)
mean dur* elemnum chnum epinum13 epinum20 Disrefnw dis01, over(bcoho), if time==1 
mean dur* elemnum chnum epinum13 epinum20 Disrefnw dis01, over(genere), if time==1 


* Pattern, tra l'atro per la seguenza modale  * 
sqtab, se

******************
* 	TABELLA 2
******************
sqtab, so




*******************************************
* 	FIGURA 2: distanze cumulate - stratificate  
*******************************************
* ringrazioamo Ulrich Kohler per il grafico. Si veda anche http://www.wzb.eu/~kohler/

lab var Disrefnw "OM Distanz"
 
by id, sort: keep if _n==1
bysort genere (Disrefnw): gen cumdis_s = (_n-.5)/_N
graph twoway ///
  || line cumdis_s Disrefnw if genere==1, sort ///
  || line cumdis_s Disrefnw if genere==2, sort name(distbysex, replace) 

* FIGURA 2a   
bysort bcoho (Disrefnw): gen cumdis_c = (_n-.5)/_N
  graph twoway ///
  || line cumdis_c Disrefnw if bcoho==4, lcolor(gs0) lwidth(thin) lstyle() sort ///
  || line cumdis_c Disrefnw if bcoho==5, lcolor(gs0) lwidth(thick)  lstyle(dot) sort ///
  || line cumdis_c Disrefnw if bcoho==6, lcolor(gs8) lwidth(thin) lstyle() sort ///
  || line cumdis_c Disrefnw if bcoho==7, lcolor(gs8) lwidth(thick) lstyle(dot) sort ///
  legend(label( 1 1963-67) label(2 1968-72	) label(3 1973-77) label(4 1978+)) ytitle("distanza cumulata") name(distbycohort, replace) 
  

 * FIGURA 2b   
 *con pesi differenziati per la sostituzione degli stati
 lab var Disrefw2_1 "OM Distanz, pesato"
 by id, sort: keep if _n==1
 bysort bcoho (Disrefw2_1): gen cumdis_c_w2 = (_n-.5)/_N
    graph twoway ///
  || line cumdis_c_w2  Disrefw2_1 if bcoho==4, lcolor(gs0) lwidth(thin) lstyle() sort ///
  || line cumdis_c_w2  Disrefw2_1 if bcoho==5, lcolor(gs0) lwidth(thick)  lstyle(dot) sort ///
  || line cumdis_c_w2  Disrefw2_1 if bcoho==6, lcolor(gs8) lwidth(thin) lstyle() sort ///
  || line cumdis_c_w2  Disrefw2_1 if bcoho==7, lcolor(gs8) lwidth(thick) lstyle(dot) sort ///
  legend(label( 1 1963-67) label(2 1968-72	) label(3 1973-77) label(4 1978+)) ytitle("distanza cumulata") name(distbycohort_w2, replace) 
  		
  
  
/*
* altrimenti 
separate Disrefnw , by(sex)
qqplot Disrefnw1 Disrefnw2 
*/



clear 
